@@ -6,7 +6,7 @@
 
 """Shell Interpreter"""
 
-import __builtin__, sys, atexit
+import sys, atexit
 from code import InteractiveConsole
 
 # Local imports:
@@ -17,49 +17,48 @@ from spyderlib.utils.dochelpers import isdefined
 STDOUT, STDERR = sys.stdout, sys.stderr
 
 
-def is_module_blacklisted(module, pathlist=[]):
-    """Return True if module path starts with one of the path in pathlist"""
-    modpath = getattr(module, '__file__', None)
-    if modpath is None:
-        # *module* is a C module that is statically linked into the interpreter
-        # There is no way to know its path, so we choose to blacklist it
-        return True
-    for path in [sys.prefix]+pathlist:
-        if modpath.startswith(path):
-            return True
-    else:
-        return False
+class UserModuleDeleter(object):
+    """
+    User Module Deleter (UMD) aims at deleting user modules 
+    to force Python to deeply reload them during import
+    
+    pathlist [list]: blacklist in terms of module path
+    namelist [list]: blacklist in terms of module name
+    """
+    def __init__(self, namelist=None, pathlist=None):
+        if namelist is None:
+            namelist = []
+        self.namelist = namelist+['sitecustomize', 'spyderlib', 'spyderplugins']
+        if pathlist is None:
+            pathlist = []
+        self.pathlist = pathlist
+        self.previous_modules = sys.modules.keys()
 
-class RollbackImporter(object):
-    """
-    Rollback importer is derived from:
-        PyUnit (Steve Purcell)
-        http://pyunit.sourceforge.net
-    """
-    def __init__(self):
-        "Creates an instance and installs as the global importer"
-        self.previous_modules = sys.modules.copy()
-        self.builtin_import = __builtin__.__import__
-        __builtin__.__import__ = self._import
-        self.new_modules = set()
+    def is_module_blacklisted(self, modname, modpath):
+        for path in [sys.prefix]+self.pathlist:
+            if modpath.startswith(path):
+                return True
+        else:
+            return set(modname.split('.')) & set(self.namelist)
         
-    def _import(self, name, globals=None, locals=None, fromlist=[], level=-1):
-        result = self.builtin_import(name, globals, locals, fromlist, level)
-        self.new_modules.add(name)
-        return result
+    def run(self):
+        """
+        Del user modules to force Python to deeply reload them
         
-    def uninstall(self):
-        blacklist = CONF.get('shell', 'rollback_importer/blacklist')
-        for name in self.new_modules:
-            if name not in self.previous_modules and name in sys.modules \
-               and not is_module_blacklisted(sys.modules[name]) \
-               and not name.split('.')[0] in blacklist:
-                try:
-                    # Force reload when modname next imported
-                    del sys.modules[name]
-                except KeyError:
-                    pass
-        __builtin__.__import__ = self.builtin_import
+        Do not del modules which are considered as system modules, i.e. 
+        modules installed in subdirectories of Python interpreter's binary
+        Do not del C modules
+        """
+        for modname, module in sys.modules.items():
+            if modname not in self.previous_modules:
+                modpath = getattr(module, '__file__', None)
+                if modpath is None:
+                    # *module* is a C module that is statically linked into the 
+                    # interpreter. There is no way to know its path, so we 
+                    # choose to ignore it.
+                    continue
+                if not self.is_module_blacklisted(modname, modpath):
+                    del sys.modules[modname]
     
 
 class Interpreter(InteractiveConsole):
@@ -75,7 +74,7 @@ class Interpreter(InteractiveConsole):
         if exitfunc is not None:
             atexit.register(exitfunc)
         
-        self.rollback_importer = None
+        self.umd = None
         
         self.namespace = self.locals
         self.namespace['__name__'] = '__main__'
@@ -89,16 +88,17 @@ class Interpreter(InteractiveConsole):
         
     def closing(self):
         """Actions to be done before restarting this interpreter"""
-        if self.rollback_importer is not None:
-            self.rollback_importer.uninstall()
+        if self.umd is not None:
+            self.umd.run()
         
-    def install_rollback_importer(self):
-        if self.rollback_importer is not None:
-            self.rollback_importer.uninstall()
-        if CONF.get('shell', 'rollback_importer'):
-            self.rollback_importer = RollbackImporter()
+    def install_umd(self):
+        if CONF.get('shell', 'umd'):
+            if self.umd is None:
+                blacklist = CONF.get('shell', 'umd/blacklist')
+                self.umd = UserModuleDeleter(namelist=blacklist)
+            self.umd.run()
         else:
-            self.rollback_importer = None
+            self.umd = None
         
     def execfile(self, filename):
         """Exec filename"""
@@ -108,7 +108,7 @@ class Interpreter(InteractiveConsole):
                 name = filename.encode('ascii')
             except UnicodeEncodeError:
                 name = '<executed_script>'
-            self.install_rollback_importer()
+            self.install_umd()
             code = compile(source, name, "exec")
         except (OverflowError, SyntaxError):
             InteractiveConsole.showsyntaxerror(self, filename)
