@@ -9,7 +9,8 @@ spyderlib.plugins
 =================
 
 Here, 'plugins' are widgets designed specifically for Spyder
-These plugins inherit the following classes (PluginMixin & PluginWidget)
+These plugins inherit the following classes
+(SpyderPluginMixin & SpyderPluginWidget)
 """
 
 # pylint: disable-msg=C0103
@@ -30,26 +31,27 @@ STDOUT = sys.stdout
 from spyderlib.utils.qthelpers import (toggle_actions, create_action,
                                        add_actions, translate)
 from spyderlib.config import CONF, get_font, set_font, get_icon
-from spyderlib.widgets.qscieditor import QsciEditor
+from spyderlib.widgets.editor import CodeEditor
 from spyderlib.widgets.findreplace import FindReplace
 
 
-class PluginMixin(object):
+class SpyderPluginMixin(object):
     """
     Useful methods to bind widgets to the main window
-    See PluginWidget class for required widget interface
+    See SpyderPluginWidget class for required widget interface
     """
-    flags = Qt.Window
-    allowed_areas = Qt.AllDockWidgetAreas
-    location = Qt.LeftDockWidgetArea
-    features = QDockWidget.DockWidgetClosable | \
+    FLAGS = Qt.Window
+    ALLOWED_AREAS = Qt.AllDockWidgetAreas
+    LOCATION = Qt.LeftDockWidgetArea
+    FEATURES = QDockWidget.DockWidgetClosable | \
                QDockWidget.DockWidgetFloatable | \
                QDockWidget.DockWidgetMovable
+    DISABLE_ACTIONS_WHEN_HIDDEN = True
     def __init__(self, main):
         """Bind widget to a QMainWindow instance"""
-        super(PluginMixin, self).__init__()
+        super(SpyderPluginMixin, self).__init__()
         self.main = main
-        self.menu_actions, self.toolbar_actions = self.set_actions()
+        self.menu_actions, self.toolbar_actions = self.get_plugin_actions()
         self.dockwidget = None
         self.ismaximized = False
         QObject.connect(self, SIGNAL('option_changed'), self.option_changed)
@@ -58,20 +60,20 @@ class PluginMixin(object):
         
     def create_dockwidget(self):
         """Add to parent QMainWindow as a dock widget"""
-        dock = QDockWidget(self.get_widget_title(), self.main)#, self.flags) -> bug in Qt 4.4
+        dock = QDockWidget(self.get_plugin_title(), self.main)#, self.FLAGS) -> bug in Qt 4.4
         dock.setObjectName(self.__class__.__name__+"_dw")
-        dock.setAllowedAreas(self.allowed_areas)
-        dock.setFeatures(self.features)
+        dock.setAllowedAreas(self.ALLOWED_AREAS)
+        dock.setFeatures(self.FEATURES)
         dock.setWidget(self)
         self.connect(dock, SIGNAL('visibilityChanged(bool)'),
                      self.visibility_changed)
         self.dockwidget = dock
-        self.refresh()
+        self.refresh_plugin()
         short = CONF.get(self.ID, "shortcut", None)
         if short is not None:
             QShortcut(QKeySequence(short), self.main,
                       lambda: self.visibility_changed(True))
-        return (dock, self.location)
+        return (dock, self.LOCATION)
     
     def create_mainwindow(self):
         """
@@ -84,9 +86,9 @@ class PluginMixin(object):
         if isinstance(icon, basestring):
             icon = get_icon(icon)
         mainwindow.setWindowIcon(icon)
-        mainwindow.setWindowTitle(self.get_widget_title())
+        mainwindow.setWindowTitle(self.get_plugin_title())
         mainwindow.setCentralWidget(self)
-        self.refresh()
+        self.refresh_plugin()
         return mainwindow
 
     def visibility_changed(self, enable):
@@ -97,10 +99,11 @@ class PluginMixin(object):
             if widget is not None:
                 widget.setFocus()
         visible = self.dockwidget.isVisible() or self.ismaximized
-        toggle_actions(self.menu_actions, visible)
-        toggle_actions(self.toolbar_actions, visible)
+        if self.DISABLE_ACTIONS_WHEN_HIDDEN:
+            toggle_actions(self.menu_actions, visible)
+            toggle_actions(self.toolbar_actions, visible)
         if visible:
-            self.refresh() #XXX Is it a good idea?
+            self.refresh_plugin() #XXX Is it a good idea?
 
     def option_changed(self, option, value):
         """
@@ -133,7 +136,7 @@ class PluginMixin(object):
         QApplication.processEvents()
 
 
-class PluginWidget(QWidget, PluginMixin):
+class SpyderPluginWidget(QWidget, SpyderPluginMixin):
     """
     Spyder base widget class
     Spyder's widgets either inherit this class or reimplement its interface
@@ -141,22 +144,23 @@ class PluginWidget(QWidget, PluginMixin):
     ID = None
     def __init__(self, parent):
         QWidget.__init__(self, parent)
-        PluginMixin.__init__(self, parent)
+        SpyderPluginMixin.__init__(self, parent)
         assert self.ID is not None
-        self.setWindowTitle(self.get_widget_title())
+        self.setWindowTitle(self.get_plugin_title())
         
-    def get_widget_title(self):
+    def get_plugin_title(self):
         """
-        Return widget title
+        Return plugin title
         Note: after some thinking, it appears that using a method
         is more flexible here than using a class attribute
         """
         raise NotImplementedError
     
-    def get_widget_icon(self):
+    def get_plugin_icon(self):
         """
-        Return widget icon name (e.g.: qt.png) or QIcon instance
-        Note: this method is used only by PluginMixin.create_mainwindow
+        Return plugin icon name (e.g.: qt.png) or QIcon instance
+        Note: this is required only for plugins creating a main window
+              (see SpyderPluginMixin.create_mainwindow)
         """
         return 'qt.png'
     
@@ -167,33 +171,38 @@ class PluginWidget(QWidget, PluginMixin):
         """
         pass
         
-    def closing(self, cancelable=False):
-        """Perform actions before parent main window is closed"""
-        # Must return True or False (if cancelable)
+    def closing_plugin(self, cancelable=False):
+        """
+        Perform actions before parent main window is closed
+        Return True or False whether the plugin may be closed immediately or not
+        Note: returned value is ignored if *cancelable* is False
+        """
         raise NotImplementedError
         
-    def refresh(self):
+    def refresh_plugin(self):
         """Refresh widget"""
         raise NotImplementedError
     
-    def set_actions(self):
-        """Setup actions"""
-        # Return menu and toolbar actions
+    def get_plugin_actions(self):
+        """
+        Setup actions and return a tuple (menu_actions, toolbar_actions)
+        (each tuple element contains a list of QAction objects or None)
+        """
         raise NotImplementedError
 
 
-class ReadOnlyEditor(PluginWidget):
+class ReadOnlyEditor(SpyderPluginWidget):
     """
     Read-only editor plugin widget
-    (see example of child class in docviewer.py)
+    (see example of child class in inspector.py)
     """
     def __init__(self, parent):
-        PluginWidget.__init__(self, parent)
+        SpyderPluginWidget.__init__(self, parent)
 
         # Read-only editor
-        self.editor = QsciEditor(self)
+        self.editor = CodeEditor(self)
         self.editor.setup_editor(linenumbers=False, language='py',
-                                 code_folding=True)
+                                 code_folding=True, scrollflagarea=False)
         self.connect(self.editor, SIGNAL("focus_changed()"),
                      lambda: self.emit(SIGNAL("focus_changed()")))
         self.editor.setReadOnly(True)
@@ -225,11 +234,11 @@ class ReadOnlyEditor(PluginWidget):
         """
         return self.editor
             
-    def set_actions(self):
-        """Setup actions"""
+    def get_plugin_actions(self):
+        """Setup and return actions"""
         return (None, None)
         
-    def closing(self, cancelable=False):
+    def closing_plugin(self, cancelable=False):
         """Perform actions before parent main window is closed"""
         return True
         
