@@ -171,19 +171,18 @@ class Console(SpyderPluginWidget):
                                     toggled=self.toggle_codecompletion_enter)
         codecompenter_action.setChecked( CONF.get(self.ID,
                                                    'codecompletion/enter-key') )
-        rollbackimporter_action = create_action(self,
+        umd_action = create_action(self,
                 self.tr("Force modules to be completely reloaded"),
                 tip=self.tr("Force Python to reload modules imported when "
                             "executing a script in the interactive console"),
                 toggled=self.toggle_rollbackimporter)
-        rollbackimporter_action.setChecked( CONF.get(self.ID,
-                                                     'rollback_importer') )
+        umd_action.setChecked( CONF.get(self.ID, 'umd') )
         
         option_menu = QMenu(self.tr("Interactive console settings"), self)
         option_menu.setIcon(get_icon('tooloptions.png'))
         add_actions(option_menu, (buffer_action, font_action, wrap_action,
                                   calltips_action, codecompletion_action,
-                                  codecompenter_action, rollbackimporter_action,
+                                  codecompenter_action, umd_action,
                                   exteditor_action))
         
         if is_module_installed('matplotlib'):
@@ -332,7 +331,7 @@ class Console(SpyderPluginWidget):
         
     def toggle_rollbackimporter(self, checked):
         """Toggle rollback importer"""
-        CONF.set(self.ID, 'rollback_importer', checked)
+        CONF.set(self.ID, 'umd', checked)
         if checked and self.isVisible():
             QMessageBox.warning(self, self.get_plugin_title(),
                         self.tr("The rollback importer requires a restart "
