@@ -926,8 +926,9 @@ class Editor(SpyderPluginWidget):
             enable = editor.is_python()
             for action in self.pythonfile_dependent_actions:
                 if action is self.winpdb_action:
-                    enable = enable and is_winpdb_installed()
-                action.setEnabled(enable)
+                    action.setEnabled(enable and is_winpdb_installed())
+                else:
+                    action.setEnabled(enable)
                 
     def update_code_analysis_actions(self):
         editorstack = self.get_current_editorstack()
@@ -1006,6 +1007,8 @@ class Editor(SpyderPluginWidget):
                 self.untitled_num += 1
                 if not osp.isfile(fname):
                     break
+            basedir = os.getcwdu()
+            fname = osp.abspath(osp.join(basedir, fname))
             editorstack.new(fname, enc, text)
         else:
             # QString when triggered by a Qt signal
@@ -1051,7 +1054,7 @@ class Editor(SpyderPluginWidget):
         editorstack = self.get_current_editorstack()
         mrf, valid = QInputDialog.getInteger(editorstack, self.tr('Editor'),
                                self.tr('Maximum number of recent files'),
-                               CONF.get(self.ID, 'max_recent_files'), 1, 100)
+                               CONF.get(self.ID, 'max_recent_files'), 1, 35)
         if valid:
             CONF.set(self.ID, 'max_recent_files', mrf)
         
@@ -1086,17 +1089,19 @@ class Editor(SpyderPluginWidget):
             self.dockwidget.setFocus()
             self.dockwidget.raise_()
         
+        def _convert(fname):
+            fname = osp.abspath(encoding.to_unicode(fname))
+            if os.name == 'nt' and len(fname) >= 2 and fname[1] == ':':
+                fname = fname[0].upper()+fname[1:]
+            return fname
         if not isinstance(filenames, (list, QStringList)):
-            filenames = [osp.abspath(encoding.to_unicode(filenames))]
+            filenames = [_convert(filenames)]
         else:
-            filenames = [osp.abspath(encoding.to_unicode(fname)) \
-                         for fname in list(filenames)]
+            filenames = [_convert(fname) for fname in list(filenames)]
         if isinstance(goto, int):
             goto = [goto]
         elif goto is not None and len(goto) != len(filenames):
             goto = None
-        if goto is None:
-            goto = [0]*len(filenames)
             
         for index, filename in enumerate(filenames):
             # -- Do not open an already opened file
@@ -1117,7 +1122,8 @@ class Editor(SpyderPluginWidget):
                 current.analyze_script() # Analyze script only once (and update
                 # all other editor instances in other editorstacks)
                 self.__add_recent_file(filename)
-            current_editor.go_to_line(goto[index], word=word)
+            if goto is not None: # 'word' is assumed to be None as well
+                current_editor.go_to_line(goto[index], word=word)
             for editor in new_editors:
                 if CONF.get(self.ID, 'fold_on_open') \
                    and CONF.get(self.ID, 'code_folding'):
@@ -1326,8 +1332,7 @@ class Editor(SpyderPluginWidget):
         (fname, wdir, ask_for_arguments,
          interact, debug, python, current) = self.__last_ec_exec
         if current:
-            self.emit(SIGNAL('run_script_in_external_console(QString)'),
-                      self.get_current_filename())
+            self.emit(SIGNAL('run_script_in_external_console(QString)'), fname)
         else:
             self.emit(SIGNAL('open_external_console(QString,QString,bool,bool,bool,bool)'),
                       fname, wdir, ask_for_arguments, interact, debug, python)
