@@ -314,11 +314,13 @@ class MainWindow(QMainWindow):
                                 triggered=self.findinfiles_callback,
                                 tip=self.tr("Search text in multiple files"))        
             def create_edit_action(text, icon_name):
+                textseq = text.split(' ')
+                method_name = textseq[0].lower()+"".join(textseq[1:])
                 return create_action(self, translate("SimpleEditor", text),
                                      shortcut=keybinding(text.replace(' ', '')),
                                      icon=get_icon(icon_name),
                                      triggered=self.global_callback,
-                                     data=text.lower(),
+                                     data=method_name,
                                      context=Qt.WidgetShortcut)
             self.undo_action = create_edit_action("Undo",'undo.png')
             self.redo_action = create_edit_action("Redo", 'redo.png')
@@ -675,10 +677,11 @@ class MainWindow(QMainWindow):
                                            'qtdesigner.png', "designer")
             qtlact = create_program_action(self, self.tr("Qt Linguist"),
                                            'qtlinguist.png', "linguist")
+            args = '-no-opengl' if os.name == 'nt' else ''
             qteact = create_python_gui_script_action(self,
                                    self.tr("Qt examples"), 'qt.png', "PyQt4",
                                    osp.join("examples", "demos",
-                                            "qtdemo", "qtdemo"))
+                                            "qtdemo", "qtdemo"), args)
             for act in (qtdact, qtlact, qteact):
                 if act:
                     additact.append(act)
