@@ -31,13 +31,16 @@ from spyderlib.utils import programs
 
 TRANSLATORS = []
 
+QAPPLICATION = None
+
 def qapplication(translate=True):
     """
     Return QApplication instance
     Creates it if it doesn't already exist
     """
+    global QAPPLICATION, TRANSLATORS
     if QApplication.startingUp():
-        app = QApplication([])
+        QAPPLICATION = QApplication([])
         if translate:
             locale = QLocale.system().name()
             # Qt-specific translator
@@ -45,15 +48,15 @@ def qapplication(translate=True):
             TRANSLATORS.append(qt_translator) # Keep reference alive
             paths = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
             if qt_translator.load("qt_"+locale, paths):
-                app.installTranslator(qt_translator)
+                QAPPLICATION.installTranslator(qt_translator)
             # Spyder-specific translator
             app_translator = QTranslator()
             TRANSLATORS.append(app_translator) # Keep reference alive
             if app_translator.load("spyder_"+locale, DATA_PATH):
-                app.installTranslator(app_translator)
-    else:
-        app = QApplication.instance()
-    return app
+                QAPPLICATION.installTranslator(app_translator)
+    elif QAPPLICATION is None:
+        QAPPLICATION = QApplication.instance()
+    return QAPPLICATION
 
 def translate(context, string):
     """Translation"""
@@ -75,7 +78,12 @@ def mimedata2url(source, extlist=None):
             path = unicode(url.toString())
             if path.startswith(r"file://"):
                 if os.name == 'nt':
-                    path = path[8:]
+                    # On Windows platforms, a local path reads: file:///c:/...
+                    # and a UNC based path reads like: file://server/share
+                    if path.startswith(r"file:///"): # this is a local path
+                        path=path[8:]
+                    else: # this is a unc path
+                        path = path[5:]
                 else:
                     path = path[7:]
             if osp.exists(path):
@@ -234,14 +242,16 @@ def create_program_action(parent, text, icon, name, nt_name=None):
         return create_action(parent, text, icon=icon,
                              triggered=lambda: programs.run_program(name))
         
-def create_python_gui_script_action(parent, text, icon, package, module):
+def create_python_gui_script_action(parent, text, icon,
+                                    package, module, args=''):
     """Create action to run a GUI based Python script"""
     if isinstance(icon, basestring):
         icon = get_icon(icon)
     if programs.is_python_gui_script_installed(package, module):
         return create_action(parent, text, icon=icon,
                              triggered=lambda:
-                             programs.run_python_gui_script(package, module))
+                             programs.run_python_gui_script(package, module,
+                                                            args))
         
 def get_std_icon(name, size=None):
     """Get standard platform icon
