@@ -141,7 +141,6 @@ class TabInfo(QObject):
         
     def cleanup_todo_results(self):
         self.todo_results = []
-        self.editor.cleanup_todo_list()
 
 
 class EditorStack(QWidget):
@@ -297,8 +296,7 @@ class EditorStack(QWidget):
             fname = other_finfo.filename
             enc = other_finfo.encoding
             finfo = self.create_new_editor(fname, enc, "", set_current=True,
-                                           clone=True)
-            finfo.editor.set_as_clone(other_finfo.editor)
+                                           cloned_from=other_finfo.editor)
             finfo.set_analysis_results(other_finfo.analysis_results)
             finfo.set_todo_results(other_finfo.todo_results)
         self.set_stack_index(other.get_stack_index())
@@ -573,8 +571,9 @@ class EditorStack(QWidget):
             return self.data[self.get_stack_index()].filename
         
     def has_filename(self, filename):
+        fixpath = lambda path: osp.normcase(osp.realpath(path))
         for index, finfo in enumerate(self.data):
-            if osp.realpath(filename) == osp.realpath(finfo.filename):
+            if fixpath(filename) == fixpath(finfo.filename):
                 return index
         
     def set_current_filename(self, filename):
@@ -596,13 +595,24 @@ class EditorStack(QWidget):
         
     #------ Close file, tabwidget...
     def close_file(self, index=None):
-        """Close current file"""
+        """
+        Close file (index=None -> close current file)
+        Keep current file index unchanged (if current file that is being closed)
+        """
+        current_index = self.get_stack_index()
+        count = self.get_stack_count()
         if index is None:
-            if self.get_stack_count():
-                index = self.get_stack_index()
+            if count > 0:
+                index = current_index
             else:
                 self.find_widget.set_editor(None)
                 return
+        new_index = None
+        if count > 1:
+            if current_index == index:
+                new_index = self._get_previous_file_index()
+            else:
+                new_index = current_index
         is_ok = self.save_if_changed(cancelable=True, index=index)
         if is_ok:
             # Removing editor reference from class browser settings:
@@ -619,6 +629,11 @@ class EditorStack(QWidget):
             self.emit(SIGNAL('update_code_analysis_actions()'))
             self._refresh_classbrowser()
             self.emit(SIGNAL('refresh_file_dependent_actions()'))
+            
+            if new_index is not None:
+                if index < new_index:
+                    new_index -= 1
+                self.set_stack_index(new_index)
         return is_ok
     
     def close_all_files(self):
@@ -825,8 +840,7 @@ class EditorStack(QWidget):
             print >>STDOUT, "current_changed:", index, self.data[index].editor,
             print >>STDOUT, self.data[index].editor.get_document_id()
         
-    def go_to_previous_file(self):
-        """Ctrl+Tab"""
+    def _get_previous_file_index(self):
         if len(self.stack_history) > 1:
             last = len(self.stack_history)-1
             w_id = self.stack_history.pop(last)
@@ -834,8 +848,13 @@ class EditorStack(QWidget):
             last_id = self.stack_history[last]
             for _i in range(self.tabs.count()):
                 if id(self.tabs.widget(_i)) == last_id:
-                    self.set_stack_index(_i)
-                    break
+                    return _i
+        
+    def go_to_previous_file(self):
+        """Ctrl+Tab"""
+        prev_index = self._get_previous_file_index()
+        if prev_index is not None:
+            self.set_stack_index(prev_index)
         elif len(self.stack_history) == 0 and self.get_stack_count():
             self.stack_history = [id(self.tabs.currentWidget())]
     
@@ -1051,7 +1070,7 @@ class EditorStack(QWidget):
         finfo.editor.set_cursor_position(position)
         
     def create_new_editor(self, fname, enc, txt,
-                          set_current, new=False, clone=False):
+                          set_current, new=False, cloned_from=None):
         """
         Create a new editor instance
         Returns finfo object (instead of editor as in previous releases)
@@ -1076,16 +1095,14 @@ class EditorStack(QWidget):
                      lambda: self.emit(SIGNAL('analysis_results_changed()')))
         self.connect(finfo, SIGNAL('todo_results_changed()'),
                      lambda: self.emit(SIGNAL('todo_results_changed()')))
-        if not clone:
-            editor.setup_editor(linenumbers=True, language=language,
-                                code_analysis=self.codeanalysis_enabled,
-                                code_folding=self.codefolding_enabled,
-                                todo_list=self.todolist_enabled,
-                                font=self.default_font,
-                                wrap=self.wrap_enabled,
-                                tab_mode=self.tabmode_enabled,
-                                occurence_highlighting=\
-                                self.occurence_highlighting_enabled)
+        editor.setup_editor(linenumbers=True, language=language,
+                code_analysis=self.codeanalysis_enabled,
+                code_folding=self.codefolding_enabled,
+                todo_list=self.todolist_enabled, font=self.default_font,
+                wrap=self.wrap_enabled, tab_mode=self.tabmode_enabled,
+                occurence_highlighting=self.occurence_highlighting_enabled,
+                cloned_from=cloned_from)
+        if cloned_from is None:
             editor.set_text(txt)
             editor.setModified(False)
         self.connect(editor, SIGNAL('cursorPositionChanged(int,int)'),
@@ -1714,6 +1731,10 @@ class FakePlugin(QSplitter):
             editorstack.set_closable( len(self.editorstacks) > 1 )
             editorstack.set_classbrowser(self.classbrowser)
             editorstack.set_find_widget(self.find_widget)
+            cb_btn = create_toolbutton(self, text_beside_icon=False)
+            cb_btn.setDefaultAction(self.classbrowser.visibility_action)
+            editorstack.add_widget_to_header(cb_btn, space_before=True)
+            
         action = QAction(self)
         editorstack.set_io_actions(action, action, action)
         font = QFont("Courier New")
@@ -1725,11 +1746,7 @@ class FakePlugin(QSplitter):
                      self.create_new_window)
         self.connect(editorstack, SIGNAL('plugin_load(QString)'),
                      self.load)
-        
-        cb_btn = create_toolbutton(self, text_beside_icon=False)
-        cb_btn.setDefaultAction(self.classbrowser.visibility_action)
-        editorstack.add_widget_to_header(cb_btn, space_before=True)
-            
+                    
     def unregister_editorstack(self, editorstack):
         if DEBUG:
             print >>STDOUT, "FakePlugin.unregister_editorstack:", editorstack
