@@ -11,7 +11,7 @@ from spyderlib.utils import select_port, fix_reference_name
 from spyderlib.utils.dochelpers import (getargtxt, getdoc, getsource, getobjdir,
                                         isdefined)
 from spyderlib.utils.iofuncs import iofunctions
-from spyderlib.widgets.dicteditor import (get_type, get_size, get_color,
+from spyderlib.widgets.dicteditor import (get_type, get_size, get_color_name,
                                           value_to_display, globalsfilter)
 
 DEBUG = False
@@ -41,7 +41,7 @@ def make_remote_view(data, settings, more_excluded_names=None):
                                 collvalue=settings['collvalue'])
         remote[key] = {'type': get_type(value),
                        'size': get_size(value),
-                       'color': get_color(value),
+                       'color': get_color_name(value),
                        'view': view}
     return remote
     
@@ -260,11 +260,11 @@ class Monitor(threading.Thread):
         self.ipython_shell = None
         from __main__ import __dict__ as glbs
         while True:
-            if self.ipython_shell is None and '__ipythonshell__' in glbs:
-                self.ipython_shell = glbs['__ipythonshell__'].IP
-                glbs = self.ipython_shell.user_ns
             try:
                 command = read_packet(self.request)
+                if self.ipython_shell is None and '__ipythonshell__' in glbs:
+                    self.ipython_shell = glbs['__ipythonshell__'].IP
+                    glbs = self.ipython_shell.user_ns
                 result = eval(command, glbs, self.locals)
                 self.locals["_"] = result
                 output = pickle.dumps(result, pickle.HIGHEST_PROTOCOL)
