@@ -202,7 +202,7 @@ class InteractiveShell(PythonShellWidget):
         self.emit(SIGNAL("refresh()"))
         
         # Installing (if enabled) Rollback Importer
-        self.interpreter.install_rollback_importer()
+        self.interpreter.install_umd()
 
         return self.interpreter
 
