@@ -112,8 +112,6 @@ class QsciEditor(TextEditBaseWidget):
         self.scrollflagarea = ScrollFlagArea(self)
         self.scrollflagarea.hide()
         
-        self.setup_editor_args = None
-        
         self.document_id = id(self)
                     
         # Indicate occurences of the selected word
@@ -224,7 +222,7 @@ class QsciEditor(TextEditBaseWidget):
             
     def resizeEvent(self, event):
         """Reimplemented Qt method to handle line number area resizing"""
-        super(QsciEditor, self).resizeEvent(event)
+        TextEditBaseWidget.resizeEvent(self, event)
         cr = self.contentsRect()
         if self.verticalScrollBar().isVisible():
             vsbw = self.verticalScrollBar().contentsRect().width()
@@ -248,19 +246,12 @@ class QsciEditor(TextEditBaseWidget):
         """Set as clone editor"""
         self.setDocument(editor.document())
         self.document_id = editor.get_document_id()
-        self.setup_editor(**editor.setup_editor_args)
         
     def setup_editor(self, linenumbers=True, language=None,
                      code_analysis=False, code_folding=False,
                      font=None, wrap=False, tab_mode=True,
                      occurence_highlighting=True, scrollflagarea=True,
-                     todo_list=True):
-        self.setup_editor_args = dict(
-                linenumbers=linenumbers, language=language,
-                code_analysis=code_analysis, code_folding=code_folding,
-                font=font, wrap=wrap, tab_mode=tab_mode,
-                occurence_highlighting=occurence_highlighting,
-                scrollflagarea=scrollflagarea, todo_list=todo_list)
+                     todo_list=True, cloned_from=None):
         
         # Scrollbar flag area
         self.set_scrollflagarea_enabled(scrollflagarea)
@@ -275,7 +266,9 @@ class QsciEditor(TextEditBaseWidget):
         self.tab_indents = language in self.TAB_ALWAYS_INDENTS
         self.set_tab_mode(tab_mode)
 
-        if font is not None:
+        if cloned_from is not None:
+            self.set_as_clone(cloned_from)
+        elif font is not None:
             self.set_font(font)
         
         if linenumbers:
@@ -297,7 +290,6 @@ class QsciEditor(TextEditBaseWidget):
         self.toggle_wrap_mode(wrap)
         if self.is_python() or self.is_cython():
             self.setup_api()
-        self.setModified(False)
         
     def set_tab_mode(self, enable):
         """
@@ -1032,7 +1024,7 @@ class QsciEditor(TextEditBaseWidget):
                            icon=get_icon('editdelete.png'),
                            triggered=self.removeSelectedText)
         selectall_action = create_action(self,
-                           translate("SimpleEditor", "Select all"),
+                           translate("SimpleEditor", "Select All"),
                            shortcut=keybinding('SelectAll'),
                            icon=get_icon('selectall.png'),
                            triggered=self.selectAll)
