@@ -16,7 +16,7 @@ import sys, re
 from PyQt4.QtGui import (QTextCursor, QColor, QFont, QApplication, QTextEdit,
                          QTextCharFormat, QToolTip, QTextDocument, QListWidget,
                          QPlainTextEdit)
-from PyQt4.QtCore import QPoint, SIGNAL, Qt
+from PyQt4.QtCore import QPoint, SIGNAL, Qt, QRegExp
 
 # Local imports
 from spyderlib.config import CONF, get_font
@@ -37,7 +37,8 @@ class CompletionWidget(QListWidget):
         self.case_sensitive = False
         self.show_single = None # see note in method 'setup'
         self.enter_select = None
-        srect = QApplication.desktop().availableGeometry(self)
+        desktop = QApplication.desktop()
+        srect = desktop.availableGeometry(desktop.screenNumber(self))
         self.screen_size = (srect.width(), srect.height())
         self.hide()
         self.connect(self, SIGNAL("itemActivated(QListWidgetItem*)"),
@@ -243,7 +244,8 @@ class TextEditBaseWidget(QPlainTextEdit):
             if position > self.get_position('eof'):
                 return
             selection = QTextEdit.ExtraSelection()
-#            selection.format.setProperty(QTextFormat.OutlinePen, QPen(color))
+#            selection.format.setProperty(QTextFormat.OutlinePen,
+#                                         QVariant(QPen(color)))
             selection.format.setBackground(color)
             selection.cursor = self.textCursor()
             selection.cursor.clearSelection()
@@ -584,20 +586,23 @@ class TextEditBaseWidget(QPlainTextEdit):
         findflag = QTextDocument.FindFlag()
         if not forward:
             findflag = findflag | QTextDocument.FindBackward
-        if case:
-            findflag = findflag | QTextDocument.FindCaseSensitively
-        if words:
-            findflag = findflag | QTextDocument.FindWholeWords
         moves = [QTextCursor.NoMove]
         if forward:
             moves += [QTextCursor.NextWord, QTextCursor.Start]
             if changed:
-                cursor.movePosition(QTextCursor.PreviousWord)
+                if cursor.selectedText().isEmpty():
+                    cursor.movePosition(QTextCursor.PreviousWord)
+                else:
+                    new_position = min([cursor.selectionStart(),
+                                        cursor.selectionEnd()])
+                    cursor.setPosition(new_position)
         else:
             moves += [QTextCursor.End]
+        regexp = QRegExp(r"\b%s\b" % QRegExp.escape(text) if words else text,
+                         Qt.CaseSensitive if case else Qt.CaseInsensitive)
         for move in moves:
             cursor.movePosition(move)
-            found_cursor = self.document().find(text, cursor, findflag)
+            found_cursor = self.document().find(regexp, cursor, findflag)
             if not found_cursor.isNull():
                 self.setTextCursor(found_cursor)
                 return True
