@@ -27,8 +27,8 @@ from PyQt4.QtGui import (QMouseEvent, QColor, QMenu, QApplication, QSplitter,
                          QFont, QTextEdit, QTextFormat, QPainter, QTextCursor,
                          QPlainTextEdit, QBrush, QTextDocument, QTextCharFormat,
                          QPixmap, QPrinter)
-from PyQt4.QtCore import (Qt, SIGNAL, QString, QEvent, QTimer, QRect,
-                          PYQT_VERSION_STR)
+from PyQt4.QtCore import (Qt, SIGNAL, QString, QEvent, QTimer, QRect, QRegExp,
+                          PYQT_VERSION_STR, QVariant)
 
 # For debugging purpose:
 STDOUT = sys.stdout
@@ -49,16 +49,9 @@ from spyderlib.utils import sourcecode, is_keyword
 # QtEditor widget
 #===============================================================================
 
-#TODO: Create an autocompletion handler (instance of a 'AutoCompletionHandler' 
-# class to be defined) and connect the 'import_statement' signal to a method of 
-# this object.
-# In this autocompletion handler, create an external shell by 
-# refactoring a lot of code from spyderlib.widgets.externalshell,
-# execute the import statements in this shell, and ask this shell 
-# about code completion thanks to already existing 'getobjdir', ...
 class QtEditor(TextEditBaseWidget):
     """
-    QScintilla Base Editor Widget
+    Source Code Editor Widget based exclusively on Qt
     """
     LANGUAGES = {
                  ('py', 'pyw', 'python'): (PythonSH, '#', PythonCFM),
@@ -126,8 +119,6 @@ class QtEditor(TextEditBaseWidget):
 
         self.update_linenumberarea_width(0)
                 
-        self.setup_editor_args = None
-        
         self.document_id = id(self)
                     
         # Indicate occurences of the selected word
@@ -178,20 +169,13 @@ class QtEditor(TextEditBaseWidget):
         """Set as clone editor"""
         self.setDocument(editor.document())
         self.document_id = editor.get_document_id()
-        self.setup_editor(**editor.setup_editor_args)
+        self.highlighter = editor.highlighter
         
     def setup_editor(self, linenumbers=True, language=None,
                      code_analysis=False, code_folding=False,
                      font=None, wrap=False, tab_mode=True,
                      occurence_highlighting=True, scrollflagarea=True,
-                     todo_list=True):
-        self.setup_editor_args = dict(
-                linenumbers=linenumbers, language=language,
-                code_analysis=code_analysis, code_folding=code_folding,
-                font=font, wrap=wrap, tab_mode=tab_mode,
-                occurence_highlighting=occurence_highlighting,
-                scrollflagarea=scrollflagarea, todo_list=todo_list)
-        
+                     todo_list=True, cloned_from=None):
         # Scrollbar flag area
         self.set_scrollflagarea_enabled(scrollflagarea)
         
@@ -207,12 +191,13 @@ class QtEditor(TextEditBaseWidget):
         # Tab always indents (even when cursor is not at the begin of line)
         self.tab_indents = language in self.TAB_ALWAYS_INDENTS
 #        self.set_tab_mode(tab_mode)
-
-        if font is not None:
-            self.set_font(font)
         
+        if cloned_from is not None:
+            self.set_as_clone(cloned_from)
+        elif font is not None:
+            self.set_font(font)
+            
         self.toggle_wrap_mode(wrap)
-        self.setModified(False)
         
     def set_tab_mode(self, enable):
         """
@@ -335,14 +320,16 @@ class QtEditor(TextEditBaseWidget):
         cursor = self.textCursor()
         # Scanning whole document
         cursor.movePosition(QTextCursor.Start)
-        cursor = self.document().find(text, cursor, flags)
+        regexp = QRegExp(r"\b%s\b" % QRegExp.escape(text), Qt.CaseSensitive)
+        cursor = self.document().find(regexp, cursor, flags)
         self.__find_first_pos = cursor.position()
         return cursor
     
     def __find_next(self, text, cursor):
         """Find next occurence"""
         flags = QTextDocument.FindCaseSensitively|QTextDocument.FindWholeWords
-        cursor = self.document().find(text, cursor, flags)
+        regexp = QRegExp(r"\b%s\b" % QRegExp.escape(text), Qt.CaseSensitive)
+        cursor = self.document().find(regexp, cursor, flags)
         if cursor.position() != self.__find_first_pos:
             return cursor
         
@@ -371,10 +358,11 @@ class QtEditor(TextEditBaseWidget):
             selection.format.setBackground(background_color)
         if underline_color is not None:
             selection.format.setProperty(QTextFormat.TextUnderlineStyle,
-                                         QTextCharFormat.SpellCheckUnderline)
+                                 QVariant(QTextCharFormat.SpellCheckUnderline))
             selection.format.setProperty(QTextFormat.TextUnderlineColor,
-                                         underline_color)
-        selection.format.setProperty(QTextFormat.FullWidthSelection, True)
+                                         QVariant(underline_color))
+        selection.format.setProperty(QTextFormat.FullWidthSelection,
+                                     QVariant(True))
         selection.cursor = cursor
         extra_selections.append(selection)
         self.set_extra_selections(key, extra_selections)
@@ -385,12 +373,22 @@ class QtEditor(TextEditBaseWidget):
         """Marking occurences of the currently selected word"""
         self.__clear_occurences()
 
-        if not self.supported_language or self.hasSelectedText():
-            return
-            
-        text = self.get_current_word()
-        if text is None:
+        if not self.supported_language:
             return
+        if self.hasSelectedText():
+            block1, block2 = self.get_selection_bounds()
+            if block1 != block2:
+                # Selection extends to more than one line
+                return
+            if not re.match(r'([a-zA-Z_]+[0-9a-zA-Z_]*)$',
+                            unicode(self.selectedText())):
+                # Selection is not a word
+                return
+            text = unicode(self.selectedText())
+        else:
+            text = self.get_current_word()
+            if text is None:
+                return
         if (self.is_python() or self.is_cython()) and is_keyword(unicode(text)):
             return
 
@@ -560,6 +558,10 @@ class QtEditor(TextEditBaseWidget):
         self.linenumberarea.setGeometry(\
                         QRect(cr.left(), cr.top(),
                               self.get_linenumberarea_width(), cr.height()))
+        self.__set_scrollflagarea_geometry(cr)
+        
+    def __set_scrollflagarea_geometry(self, contentrect):
+        cr = contentrect
         if self.verticalScrollBar().isVisible():
             vsbw = self.verticalScrollBar().contentsRect().width()
         else:
@@ -578,19 +580,22 @@ class QtEditor(TextEditBaseWidget):
     def viewportEvent(self, event):
         # 80-column edge line
         cr = self.contentsRect()
+        offset = self.contentOffset()
         x = self.blockBoundingGeometry(self.firstVisibleBlock()) \
-            .translated(self.contentOffset()).left() \
+            .translated(offset.x(), offset.y()).left() \
             +self.linenumberarea.contentsRect().width() \
             +self.fontMetrics().width('9')*self.edge_line.column+5
         self.edge_line.setGeometry(\
                         QRect(x, cr.top(), 1, cr.bottom()))
+        self.__set_scrollflagarea_geometry(cr)
         return super(QtEditor, self).viewportEvent(event)
 
     #-----highlight current line
     def highlight_current_line(self):
         """Highlight current line"""
         selection = QTextEdit.ExtraSelection()
-        selection.format.setProperty(QTextFormat.FullWidthSelection, True)
+        selection.format.setProperty(QTextFormat.FullWidthSelection,
+                                     QVariant(True))
         selection.format.setBackground(self.currentline_color)
         selection.cursor = self.textCursor()
         selection.cursor.clearSelection()
@@ -645,8 +650,7 @@ class QtEditor(TextEditBaseWidget):
         # Standard paste
         TextEditBaseWidget.paste(self)
 
-    def get_block_data(self, block_nb):
-        block = self.document().findBlockByNumber(block_nb)
+    def get_block_data(self, block):
         return self.highlighter.block_data.get(block)
 
     def get_fold_level(self, block_nb):
@@ -717,7 +721,9 @@ class QtEditor(TextEditBaseWidget):
                     line2 += 1
                 cursor.setPosition(document.findBlockByNumber(line1).position())
                 cursor.movePosition(QTextCursor.StartOfBlock)
-                cursor = document.find(text, cursor, flags)
+                regexp = QRegExp(r"\b%s\b" % QRegExp.escape(text),
+                                 Qt.CaseSensitive)
+                cursor = document.find(regexp, cursor, flags)
                 self.__highlight_selection('code_analysis', cursor,
                                    underline_color=QColor(self.warning_color))
 #                old_pos = None
@@ -1043,7 +1049,7 @@ class QtEditor(TextEditBaseWidget):
                            icon=get_icon('editdelete.png'),
                            triggered=self.removeSelectedText)
         selectall_action = create_action(self,
-                           translate("SimpleEditor", "Select all"),
+                           translate("SimpleEditor", "Select All"),
                            shortcut=keybinding('SelectAll'),
                            icon=get_icon('selectall.png'),
                            triggered=self.selectAll)
@@ -1062,6 +1068,9 @@ class QtEditor(TextEditBaseWidget):
         key = event.key()
         ctrl = event.modifiers() & Qt.ControlModifier
         shift = event.modifiers() & Qt.ShiftModifier
+        text = unicode(event.text())
+        if text:
+            self.__clear_occurences()
         # Zoom in/out
         if key in (Qt.Key_Enter, Qt.Key_Return) and not shift and not ctrl:
             QPlainTextEdit.keyPressEvent(self, event)
