@@ -11,11 +11,12 @@
 # pylint: disable-msg=R0911
 # pylint: disable-msg=R0201
 
-import sys, os, time
+import sys, os, time, string
 import os.path as osp
 
 from PyQt4.QtGui import (QMenu, QApplication, QCursor, QToolTip, QKeySequence,
-                         QFileDialog, QMessageBox, QMouseEvent)
+                         QFileDialog, QMessageBox, QMouseEvent, QTextCursor,
+                         QTextCharFormat)
 from PyQt4.QtCore import Qt, QString, QCoreApplication, SIGNAL, pyqtProperty
 
 # For debugging purpose:
@@ -97,6 +98,12 @@ class ShellBaseWidget(ConsoleBaseWidget):
     def set_font(self, font):
         """Set shell styles font"""
         self.set_pythonshell_font(font)
+        cursor = self.textCursor()
+        cursor.select(QTextCursor.Document)
+        charformat = QTextCharFormat()
+        charformat.setFontFamily(font.family())
+        charformat.setFontPointSize(font.pointSize())
+        cursor.mergeCharFormat(charformat)
 
 
     #------ Context menu
@@ -132,7 +139,7 @@ class ShellBaseWidget(ConsoleBaseWidget):
                                     icon=get_icon('editdelete.png'),
                                     triggered=self.delete)
         selectall_action = create_action(self,
-                                    translate("ShellBaseWidget", "Select all"),
+                                    translate("ShellBaseWidget", "Select All"),
                                     shortcut=keybinding('SelectAll'),
                                     icon=get_icon('selectall.png'),
                                     triggered=self.selectAll)
@@ -903,14 +910,10 @@ class PythonShellWidget(ShellBaseWidget):
     #------ Code Completion / Calltips        
     def show_completion_list(self, completions, completion_text=""):
         """Display the possible completions"""
-        if len(completions) == 0 or completion_text in completions:
+        if len(completions) == 0 or completions == [completion_text]:
             return
         self.completion_text = completion_text
-        if isinstance(completions[0], unicode):
-            key = unicode.lower
-        else:
-            key = str.lower
-        self.show_completion_widget(sorted(completions, key=key))
+        self.show_completion_widget(sorted(completions, key=string.lower))
 
     # Methods implemented in child class:
     # (e.g. InteractiveShell)
@@ -993,9 +996,11 @@ class PythonShellWidget(ShellBaseWidget):
             else:
                 completion_text = last_obj[dot_pos+1:]
                 last_obj = last_obj[:dot_pos]
-            self.show_completion_list(self.get_dir(last_obj),
-                                      completion_text=completion_text)
-            return
+            completions = self.get_dir(last_obj)
+            if completions is not None:
+                self.show_completion_list(completions,
+                                          completion_text=completion_text)
+                return
         
         # Looking for ' or ": filename completion
         q_pos = max([text.rfind("'"), text.rfind('"')])
